pub enum Command {
Show 14 variants
Config(ConfigCmd),
Mcp,
Zone(ZoneCmd),
Record(RecordCmd),
Query(QueryArgs),
Sync {
profile: Option<String>,
from: Option<String>,
to: Option<String>,
zone: Vec<String>,
map: Vec<String>,
apply: bool,
json: bool,
},
Cache(CacheCmd),
Stats {
type: String,
},
Blocked(BlockedCmd),
Allowed(AllowedCmd),
Settings {
show_secrets: bool,
},
Logs {
lines: u32,
start: Option<String>,
end: Option<String>,
level: Option<LogLevel>,
},
Completions {
shell: Shell,
},
ServerIds,
}Variants
Config(ConfigCmd)
Write a starter config file
Mcp
Start the MCP stdio server
Zone(ZoneCmd)
Manage DNS zones
Record(RecordCmd)
Manage DNS records
Query(QueryArgs)
Resolve a name directly against the system, a configured server, or any
ad-hoc nameserver. Supports DNS, DoT, DoH, and (with --features doq)
DoQ transports.
Sync
Sync records between two configured servers, optionally remapping IPs
Fields
Cache(CacheCmd)
Manage the DNS cache
Stats
View server statistics
Blocked(BlockedCmd)
Manage manually blocked domains
Allowed(AllowedCmd)
Manage the allowed (whitelist) domains
Settings
Show server settings
Logs
Fetch DNS server logs
Fields
Completions
Print a shell completion script to stdout.
Redirect the output to a file in your shell’s completions directory: dns completions fish > ~/.config/fish/completions/dns.fish dns completions bash > ~/.local/share/bash-completion/completions/dns dns completions zsh > ~/.zsh/completions/_dns
ServerIds
Print configured server IDs (used by shell completions)