Module access_lists

Module access_lists 

Functions

add_allowed
Add a domain to the allowed list through a vendor-neutral access-list writer.
add_blocked
Add a domain to the blocked list through a vendor-neutral access-list writer.
delete_allowed
Delete a domain from the allowed list through a vendor-neutral access-list writer.
delete_blocked
Delete a domain from the blocked list through a vendor-neutral access-list writer.
list_allowed
List manually allowed DNS domains through a vendor-neutral access-list reader.
list_blocked
List manually blocked DNS domains through a vendor-neutral access-list reader.