pub struct RecordValidationResult {
pub name: String,
pub record_type: String,
pub status: ValidationStatus,
pub mismatch: Option<RecordMismatch>,
pub failure_kind: Option<ValidationFailureKind>,
pub skip_reason: Option<String>,
}Expand description
Validation result for one expected record.
Fields
name: Stringrecord_type: Stringstatus: ValidationStatusmismatch: Option<RecordMismatch>failure_kind: Option<ValidationFailureKind>skip_reason: Option<String>Trait Implementations
Sourceimpl Clone for RecordValidationResult
impl Clone for RecordValidationResult
Sourcefn clone(&self) -> RecordValidationResult
fn clone(&self) -> RecordValidationResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecordValidationResult
impl Debug for RecordValidationResult
Sourceimpl<'de> Deserialize<'de> for RecordValidationResult
impl<'de> Deserialize<'de> for RecordValidationResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RecordValidationResult
impl JsonSchema for RecordValidationResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RecordValidationResult
impl PartialEq for RecordValidationResult
Sourcefn eq(&self, other: &RecordValidationResult) -> bool
fn eq(&self, other: &RecordValidationResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for RecordValidationResult
impl Serialize for RecordValidationResult
impl Eq for RecordValidationResult
impl StructuralPartialEq for RecordValidationResult