pub struct ValidationReport {
pub enabled: bool,
pub status: ValidationStatus,
pub zone: Option<String>,
pub domain: Option<String>,
pub phase: Option<String>,
pub endpoints: Vec<EndpointValidationReport>,
pub results: Vec<RecordValidationResult>,
pub mismatches: Vec<RecordMismatch>,
pub skipped: Vec<SkippedRecord>,
pub failures: Vec<ValidationFailureKind>,
}Expand description
Stable validation report shape for record lists and transfer pre/post checks.
Fields
enabled: boolstatus: ValidationStatuszone: Option<String>domain: Option<String>phase: Option<String>Optional report phase, such as record_list, transfer_pre, or transfer_post.
endpoints: Vec<EndpointValidationReport>results: Vec<RecordValidationResult>mismatches: Vec<RecordMismatch>skipped: Vec<SkippedRecord>failures: Vec<ValidationFailureKind>Implementations
Sourceimpl ValidationReport
impl ValidationReport
Sourcepub fn skipped_no_endpoints() -> Self
pub fn skipped_no_endpoints() -> Self
Build a report for enabled validation with no configured endpoints.
Sourcepub fn skipped(reason: &str) -> Self
pub fn skipped(reason: &str) -> Self
Build a report for enabled validation skipped for a specific reason.
Sourcepub const fn overall_status(&self) -> &ValidationStatus
pub const fn overall_status(&self) -> &ValidationStatus
Return the aggregate report status.