pub trait DnsEndpointResolver {
// Required method
fn query_endpoint<'a>(
&'a self,
endpoint: &'a ValidationEndpointConfig,
fqdn: &'a str,
record_type: &'a str,
timeout: Duration,
) -> impl Future<Output = DnsEndpointResolverResult<Vec<ObservedRecord>>> + Send + 'a;
}Expand description
Async DNS endpoint resolver abstraction used by validation code.
Implementations query one configured endpoint for one FQDN and record type. Tests can implement this trait without opening network sockets.
Required Methods
Sourcefn query_endpoint<'a>(
&'a self,
endpoint: &'a ValidationEndpointConfig,
fqdn: &'a str,
record_type: &'a str,
timeout: Duration,
) -> impl Future<Output = DnsEndpointResolverResult<Vec<ObservedRecord>>> + Send + 'a
fn query_endpoint<'a>( &'a self, endpoint: &'a ValidationEndpointConfig, fqdn: &'a str, record_type: &'a str, timeout: Duration, ) -> impl Future<Output = DnsEndpointResolverResult<Vec<ObservedRecord>>> + Send + 'a
Query a validation endpoint for records visible at that endpoint.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".